@@ -128,10 +128,11 @@ class VoiceTextContext(c.Context):
 
         self.default_params = {
             "server": self.guild.id,
-            "vc": self.author.voice.channel.id,
             "tc": self.channel.id,
             "opt": self.bot.user.id
         }
+        if (voice := self.author.voice):
+            self.default_params["vc"] = voice.channel.id
 
         # 話者
         self.speaker = {
